pub fn open_data(uri_str: &str) -> Result<Box<dyn BytesSource>>Expand description
Open a data: URI as a BytesSource. Equivalent to parse
followed by wrapping the decoded bytes in a Cursor.
pub fn open_data(uri_str: &str) -> Result<Box<dyn BytesSource>>Open a data: URI as a BytesSource. Equivalent to parse
followed by wrapping the decoded bytes in a Cursor.